======
BYCEPS
======

BYCEPS is the Bring-Your-Computer Event Processing System.

It is **a tool to prepare and operate a LAN party**, both online on the
Internet and locally as an intranet system, for both organizers and
attendees.


Installation
============

For the time being, BYCEPS cannot be installed with
``pip install byceps`` from PyPI. Please see the website to learn how to
install it.


Website
=======

The official BYCEPS website is at https://byceps.nwsnet.de/.


Author
======

BYCEPS was created, and is developed and maintained, by Jochen "Y0Gi"
Kupperschmidt.


License
=======

BYCEPS is licensed under the `BSD 3-Clause "New" or "Revised" License
<https://choosealicense.com/licenses/bsd-3-clause/>`_.
